==> moodle-1.5-pgsql.tgz: moodle/lang/hu/block_rss_client.php <==
<?PHP // $Id$ 
      // block_rss_client.php - created with Moodle 1.4 (2004083100)


$string['addfeed'] = 'Hrfrum URL-jnek hozzadsa';
$string['addheadlineblock'] = 'RSS-fejcmblokk hozzadsa';
$string['addnew'] = 'j hozzadsa';
$string['choosefeedlabel'] = 'Vlassza ki a blokkbl elrni kvnt hreket:';
$string['clientchannellink'] = 'Forrsportl...';
$string['clientnumentries'] = 'Hrfrumonknt megjelentend hrek szma';
$string['clientshowchannellinklabel'] = 'Ltsszon az eredeti helyre (csatorna) mutat ugrpont? (Ha a hrek nem tartalmaznak ugrpontot a hrfrumokra, nem jelenik meg ugrpont): ';
$string['clientshowimagelabel'] = 'Csatornakp megjelentse, ha van:';
$string['configblock'] = 'Blokk belltsa';
$string['couldnotfindfeed'] = 'Az azonostval nem talltam hrt';
$string['customtitlelabel'] = 'Testre szabott cm (resen hagyva a hr cme jelenik meg):';
$string['deletefeedconfirm'] = 'Biztosan tlni akarja ezt a hrt?';
$string['displaydescriptionlabel'] = 'Minden ugrpont lersa jelenjen meg?';
$string['editfeeds'] = 'RSS/Atom frumhrek szerkesztse, jratsa vagy leratkozs';
$string['editnewsfeeds'] = 'Frumhrek szerkesztse';
$string['editrssblock'] = 'RSS-fejcmblokk szerkesztse';
$string['feed'] = 'Hr';
$string['feedadded'] = 'Frumhr hozzadva';
$string['feeddeleted'] = 'Frumhr trlve';
$string['feeds'] = 'Frumhrek';
$string['feedsaddedit'] = 'Hr hozzadsa/szerkesztse';
$string['feedsconfigurenewinstance'] = 'Ide kattintva a blokkot bellthatja az RSS-hrek megjelentsre';
$string['feedstitle'] = 'Tvoli  RSS-hrek';
$string['feedupdated'] = 'Frumhrek frisstve';
$string['findmorefeeds'] = 'Ms RSS-hrek keresse';
$string['managefeeds'] = 'Minden hrem kezelse';
$string['nofeeds'] = 'Ezen az oldalon nincsenek RSS-hrek';
$string['pickfeed'] = 'Frumhr vlasztsa';
$string['remotenewsfeed'] = 'Tvoli frumhr';
$string['seeallfeeds'] = 'Minden hr megtekintse';
$string['shownumentrieslabel'] = 'Blokkonknt kijelzend ttelek max. szma';
$string['submitters'] = 'Ki adhat meg j RSS-hrt? A megadott hrek a portljn brhol elrhetk.';
$string['timeout'] = 'blockrsstimeout';
$string['timeoutdesc'] = 'Egy RSS-hr ennyi percig maradhat a gyorsttrban.';
$string['updatefeed'] = 'Frumhr URL-jnek frisstse:';
$string['validatefeed'] = 'Hr ellenrzse';

?>

==> moodle-1.5.3-pgsql.tgz: moodle/lang/hu/block_rss_client.php <==
<?PHP // $Id$ 
      // block_rss_client.php - created with Moodle 1.4 (2004083100)


$string['addfeed'] = 'Hrfrum URL-jnek hozzadsa';
$string['addheadlineblock'] = 'RSS-fejcmblokk hozzadsa';
$string['addnew'] = 'j hozzadsa';
$string['choosefeedlabel'] = 'Vlassza ki a blokkbl elrni kvnt hreket:';
$string['clientchannellink'] = 'Forrsportl...';
$string['clientnumentries'] = 'Hrfrumonknt megjelentend hrek szma';
$string['clientshowchannellinklabel'] = 'Ltsszon az eredeti helyre (csatorna) mutat ugrpont? (Ha a hrek nem tartalmaznak ugrpontot a hrfrumokra, nem jelenik meg ugrpont): ';
$string['clientshowimagelabel'] = 'Csatornakp megjelentse, ha van:';
$string['configblock'] = 'Blokk belltsa';
$string['couldnotfindfeed'] = 'Az azonostval nem talltam hrt';
$string['customtitlelabel'] = 'Testre szabott cm (resen hagyva a hr cme jelenik meg):';
$string['deletefeedconfirm'] = 'Biztosan tlni akarja ezt a hrt?';
$string['displaydescriptionlabel'] = 'Minden ugrpont lersa jelenjen meg?';
$string['editfeeds'] = 'RSS/Atom frumhrek szerkesztse, jratsa vagy leiratkozs';
$string['editnewsfeeds'] = 'Frumhrek szerkesztse';
$string['editrssblock'] = 'RSS-fejcmblokk szerkesztse';
$string['feed'] = 'Hr';
$string['feedadded'] = 'Frumhr hozzadva';
$string['feeddeleted'] = 'Frumhr trlve';
$string['feeds'] = 'Frumhrek';
$string['feedsaddedit'] = 'Hr hozzadsa/szerkesztse';
$string['feedsconfigurenewinstance'] = 'Ide kattintva a blokkot bellthatja az RSS-hrek megjelentsre';
$string['feedstitle'] = 'Tvoli  RSS-hrek';
$string['feedupdated'] = 'Frumhrek frisstve';
$string['findmorefeeds'] = 'Ms RSS-hrek keresse';
$string['managefeeds'] = 'Minden hrem kezelse';
$string['nofeeds'] = 'Ezen az oldalon nincsenek RSS-hrek';
$string['pickfeed'] = 'Frumhr vlasztsa';
$string['remotenewsfeed'] = 'Tvoli frumhr';
$string['seeallfeeds'] = 'Minden hr megtekintse';
$string['shownumentrieslabel'] = 'Blokkonknt kijelzend ttelek max. szma';
$string['submitters'] = 'Ki adhat meg j RSS-hrt? A megadott hrek a portljn brhol elrhetk.';
$string['timeout'] = 'blockrsstimeout';
$string['timeoutdesc'] = 'Egy RSS-hr ennyi percig maradhat a gyorsttrban.';
$string['updatefeed'] = 'Frumhr URL-jnek frisstse:';
$string['validatefeed'] = 'Hr ellenrzse';

?>
